using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using Syncfusion.Windows.Forms.Grid.Grouping;
using Syncfusion.Grouping;

namespace _2942
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        void Table_RecordExpanded(object sender, RecordEventArgs e)
        {
            Console.WriteLine("RecordExpanded event handled...");
        }

        #region datatables
        private int numberParentRows = 10;
        private int numberChildRows = 20;
        private DataTable GetParentTable()
        {
            DataTable dt = new DataTable("ParentTable");


            dt.Columns.Add(new DataColumn("OPERATIONNO"));
            dt.Columns.Add(new DataColumn("SomethingEXIST"));
            dt.Columns.Add(new DataColumn("Checked", typeof(bool)));

            Random ran = new Random();
            for (int i = 0; i < numberParentRows; ++i)
            {
                DataRow dr = dt.NewRow();
                dr[0] = i;
                dr[1] = ran.Next(100) % 2;
                dr[2] = true;
                dt.Rows.Add(dr);
            }

            dt.PrimaryKey = new DataColumn[] { dt.Columns["parentID"] };

            return dt;
        }

        private DataTable GetChildTable()
        {
            DataTable dt = new DataTable("ChildTable");

            dt.Columns.Add(new DataColumn("childID")); 
            dt.Columns.Add(new DataColumn("OPERATIONNO"));
            dt.Columns.Add(new DataColumn("SomethingEXIST"));
            dt.Columns.Add(new DataColumn("Checked", typeof(bool)));
            Random ran = new Random();
            for (int i = 0; i < numberChildRows; ++i)
            {
               
                    DataRow dr = dt.NewRow();
                    dr[0] = i.ToString();
                    dr[1] = (i % numberParentRows).ToString();
                    dr[2] = ran.Next(100) % 2; ;
                    dr[3] = true;
                    dt.Rows.Add(dr);
           
            }

            return dt;
        }

        #endregion

        private void ShowGridGrouping(DataSet dsQCOp, DataSet dsQCDefect)
        {
            DataSet ds = new DataSet();
            if (dsQCOp != null)
            {
                ds.Tables.Add(dsQCOp.Tables[0].Copy());
                ds.Tables[0].TableName = "QC_OPERATION";

                if (dsQCDefect != null)
                {
                    ds.Tables.Add(dsQCDefect.Tables[0].Copy());
                    ds.Tables[1].TableName = "QC_DEFECT";


                    ds.Relations.Add(ds.Tables[0].Columns["OPERATIONNO"],
                        ds.Tables[1].Columns["OPERATIONNO"]);
                    ds.Relations[0].RelationName = "QCOPERATIONNO";

                }

                this.gridGroupingControl1.DataSource = ds.Tables[0];

                GridEngine engine = this.gridGroupingControl1.Engine;

                //grid properties setting
                engine.TopLevelGroupOptions.ShowCaption = false;
                engine.TopLevelGroupOptions.ShowAddNewRecordBeforeDetails = false;

                //QC Operation
                GridTableDescriptor qcOpTableDescriptor = (GridTableDescriptor)engine.TableDescriptor;
                qcOpTableDescriptor.Columns.Clear();
                qcOpTableDescriptor.Columns.Add("OPERATIONNO");

                if (dsQCDefect != null)
                {
                    RelationDescriptor opDefectRelationDescriptor = qcOpTableDescriptor.Relations["QC_DEFECT"];
                    GridTableDescriptor opDefectTableDescriptor = (GridTableDescriptor)opDefectRelationDescriptor.ChildTableDescriptor;

                    opDefectTableDescriptor.AllowEdit = false;
                    opDefectTableDescriptor.AllowNew = false;
                    opDefectTableDescriptor.TopLevelGroupOptions.ShowCaption = false;
                }

            }
        }

        private void button1_Click(object sender, EventArgs e)
        {
            DataSet ds1 = new DataSet();
            DataSet ds2 = new DataSet();

            ds1.Tables.Add(this.GetParentTable());
            ds2.Tables.Add(this.GetChildTable());

            ShowGridGrouping(ds1, ds2);
        }

        private void gridGroupingControl1_TableControlCellClick(object sender, GridTableControlCellClickEventArgs e)
        {
            Console.WriteLine("TableControlCellClick event handled...");
        }

        private void button2_Click(object sender, EventArgs e)
        {
            this.gridGroupingControl1.Table.RecordExpanded += new RecordEventHandler(Table_RecordExpanded);
        }

        private void button3_Click(object sender, EventArgs e)
        {
            this.gridGroupingControl1.Table.RecordExpanded -= new RecordEventHandler(Table_RecordExpanded);
        }

    }
}